from django.core.urlresolvers import reverse
from django.http import JsonResponse, HttpResponseBadRequest
from django.shortcuts import redirect
from django.template import RequestContext
from django.template.loader import render_to_string
from django.utils import timezone
from django.views.decorators.http import require_POST

from django.contrib.auth.decorators import permission_required

from .forms import BoxForm
from .models import Box


@require_POST
@permission_required("boxes.change_box", raise_exception=True)
def box_edit(request, label):
    box, _ = Box.objects.get_or_create(label=label, defaults={
        "created_by": request.user,
        "last_updated_by": request.user
    })
    form = BoxForm(request.POST, instance=box, prefix=label)

    if not form.is_valid():
        return HttpResponseBadRequest()  # not sure how this will ever happen

    box = form.save(commit=False)
    box.last_updated_by = request.user
    box.last_updated = timezone.now()
    box.save()

    if not request.is_ajax():
        return redirect(
            request.POST.get("next", request.GET.get("next", request.path))
        )

    data = {
        "html": render_to_string("boxes/_box_body.html", {
            "label": label,
            "form": BoxForm(instance=box, prefix=label),
            "box": box,
            "form_action": reverse("box_edit", args=[label]),
            "saved": True
        }, context_instance=RequestContext(request))
    }
    return JsonResponse(data)



import codecs

from os import path
from setuptools import find_packages, setup


def read(*parts):
    filename = path.join(path.dirname(__file__), *parts)
    with codecs.open(filename, encoding="utf-8") as fp:
        return fp.read()


setup(
    author="Pinax Team",
    author_email="developers@pinaxproject.com",
    description="An app for including boxes of admin-controllable content in templates.",
    name="pinax-boxes",
    long_description=read("README.rst"),
    version="2.0.1",
    url="http://github.com/pinax/pinax-boxes/",
    license="MIT",
    packages=find_packages(),
    package_data={
        "boxes": []
    },
    test_suite="runtests.runtests",
    tests_require=[
    ],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    zip_safe=False
)



from django.db import models
from django.utils import timezone

from django.contrib.auth.models import User


class Box(models.Model):

    label = models.CharField(max_length=100, db_index=True)
    content = models.TextField(blank=True)
    created_by = models.ForeignKey(User, related_name="boxes")
    last_updated_by = models.ForeignKey(User, related_name="updated_boxes")
    last_updated = models.DateTimeField(default=timezone.now)

    def __unicode__(self):
        return self.label

    class Meta:
        verbose_name_plural = "boxes"
